@@ -75,7 +75,6 @@ void pathdefaults(pathptr newpath, int x, int y)
    newpath->parts = 0;
    newpath->plist = (genericptr *)NULL;
    newpath->passed = NULL;
-   newpath->num_params = 0;
 }
 
 /*---------------------------------------*/
@@ -92,7 +91,6 @@ void objectdefaults(objinstptr newinst, objectptr thisobj, int x, int y)
    newinst->color = areastruct.color;
    newinst->params = NULL;
    newinst->passed = NULL;
-   newinst->num_params = 0;
 
    newinst->bbox.lowerleft.x = thisobj->bbox.lowerleft.x;
    newinst->bbox.lowerleft.y = thisobj->bbox.lowerleft.y;
@@ -129,7 +127,6 @@ void drawdot(int xpos, int ypos)
       (*newarc)->yaxis = 6;
       (*newarc)->width = 1.0;
       (*newarc)->style = FILLED | FILLSOLID | NOBORDER;
-      (*newarc)->num_params = 0;
       (*newarc)->passed = NULL;
       calcarc(*newarc);
    }
@@ -171,7 +168,6 @@ void labeldefaults(labelptr newlabel, u_char dopin, int x, int y)
    newlabel->color = areastruct.color;
    newlabel->scale = areastruct.textscale;
    newlabel->string = (stringpart *)malloc(sizeof(stringpart));
-   newlabel->num_params = 0;
    newlabel->passed = NULL;
 
    /* initialize string with font designator */
@@ -446,6 +442,7 @@ void labeltext(int keypressed, char *clientdata)
       }
       else
          calcbbox(areastruct.topinstance);
+
       return;
    }
    else if (isbound(keypressed, XCF_Text_Right) && curpos != NULL)
@@ -523,6 +520,7 @@ void labeltext(int keypressed, char *clientdata)
    /* Write a font designator or other control into the string */
 
    if (clientdata != NULL) {
+      oparamptr ops;
       stringpart *newpart;
       Boolean errcond = False;
 
@@ -551,10 +549,11 @@ void labeltext(int keypressed, char *clientdata)
 	    if (newpart->data.font >= fontcount) errcond = True;
 	    break;
 	 case PARAM_START:
-	    newpart->data.paramno = *((int *)clientdata);
-	    if (newpart->data.paramno >= topobject->num_params) errcond = True;
-	    else if (topobject->params[newpart->data.paramno]->type != XC_STRING)
-	       errcond = True;
+	    newpart->data.string = (char *)malloc(1 + strlen(clientdata));
+	    strcpy(newpart->data.string, clientdata);
+	    ops = match_param(topobject, clientdata);
+	    if (ops == NULL) errcond = True;
+	    else if (ops->type != XC_STRING) errcond = True;
 	    break;
       }
       if (errcond == True) {
@@ -709,7 +708,6 @@ void rejustify(short mode)
    else if (changed) {
       pwriteback(areastruct.topinstance);
       incr_changes(topobject);
-
    }
 }
 
@@ -730,7 +728,6 @@ void splinedefaults(splineptr newspline, int x, int y)
    newspline->width = areastruct.linewidth;
    newspline->style = areastruct.style;
    newspline->color = areastruct.color;
-   newspline->num_params = 0;
    newspline->passed = NULL;
    calcspline(newspline);
 }
@@ -834,7 +831,6 @@ void arcdefaults(arcptr newarc, int x, int y)
    newarc->yaxis = 0;
    newarc->angle1 = 0;
    newarc->angle2 = 360;
-   newarc->num_params = 0;
    newarc->passed = NULL;
    calcarc(newarc);
 }
@@ -958,7 +954,6 @@ void polydefaults(polyptr newpoly, int number, int x, int y)
    newpoly->width = areastruct.linewidth;
    newpoly->number = number;
    newpoly->points = (pointlist) malloc(number * sizeof(XPoint));
-   newpoly->num_params = 0;
    newpoly->passed = NULL;
    for (pointptr = newpoly->points; pointptr < newpoly->points + number;
 	pointptr++) {
@@ -1065,7 +1060,6 @@ void startwire(XPoint userpt)
    (*newwire)->number = 2;
    (*newwire)->width = areastruct.linewidth;
    (*newwire)->points = (pointlist) malloc(2 * sizeof(XPoint));
-   (*newwire)->num_params = 0;
    (*newwire)->passed = NULL;
    pointptr = (*newwire)->points;
    pointptr->x = (pointptr + 1)->x = areastruct.save.x = userpt.x;
@@ -1574,7 +1568,6 @@ void join()
       (*newpoly)->width  = polywidth;
       (*newpoly)->style  = polytype;
       (*newpoly)->color  = polycolor;
-      (*newpoly)->num_params = 0;
       (*newpoly)->passed = NULL;
 
       /* insert the points into the new polygon */
@@ -1624,7 +1617,6 @@ void join()
       (*newpath)->width = polywidth;
       (*newpath)->parts = numpolys;
       (*newpath)->plist = (genericptr *) malloc(numpolys * sizeof(genericptr));
-      (*newpath)->num_params = 0;
       (*newpath)->passed = NULL;
 
       /* move the elements from the top level into the path structure */
