@@ -10,11 +10,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#if defined(DARWIN)
-#include <sys/malloc.h>
-#else
-#include <malloc.h>
-#endif
 #include <math.h>
 
 #include <X11/Intrinsic.h>
@@ -1186,7 +1181,7 @@ void updateinstparam(objectptr bobj, int mode)
 	       /* substitutions.						*/
 
 	       objinstptr cinst = TOOBJINST(pageobj->plist + j);
-	       if (cinst->thisobject->num_params == 0) {
+	       if (cinst->thisobject->params == NULL) {
 	          calcbboxvalues(xobjs.pagelist[i]->pageinst, pageobj->plist + j);
 	          updatepagelib(PAGELIB, i);
 	       }
