@@ -2265,7 +2265,7 @@ void startparam(xcWidget w, pointertype value, caddr_t calldata)
          eventmode = IPARAM_MODE;
          Wprintf("Click on object to parameterize.");
       }      
-      else parameterize((int)value, NULL);
+      else parameterize((int)value, (char *)calldata);
    }
 }
 
