@@ -538,7 +538,7 @@ extern oparamptr make_new_parameter(char *);
 extern eparamptr make_new_eparam(char *);
 
 extern void indicateparams(genericptr);
-extern void makenumericalp(genericptr *, u_int);
+extern void makenumericalp(genericptr *, u_int, char *);
 extern void noparmstrcpy(u_char *, u_char *);
 extern void insertparam();
 extern void makeparam(labelptr, char *);
@@ -553,6 +553,7 @@ extern Boolean paramcross(objectptr, labelptr);
 extern oparamptr parampos(objectptr, labelptr, char *, short *, short *);
 extern int opsubstitute(objectptr, objinstptr);
 extern int psubstitute(objinstptr);
+extern oparamptr copyparameter(oparamptr);
 extern void pwriteback(objinstptr);
 extern short paramlen(u_char *);
 extern int natstrlen(u_char *);
