@@ -263,7 +263,10 @@ stringpart *deletestring(stringpart *dstr, stringpart **strtop, objinstptr thisi
 
 stringpart *mergestring(stringpart *firststr)
 {
-   stringpart *nextstr = firststr->nextpart;
+   stringpart *nextstr;
+
+   if (!firststr) return NULL;
+   nextstr = firststr->nextpart;
    if (nextstr != NULL) {
       if (firststr->type == TEXT_STRING && nextstr->type == TEXT_STRING) {
          firststr->nextpart = nextstr->nextpart;
