@@ -483,9 +483,12 @@ typedef struct _oparam {
 typedef struct _eparam *eparamptr;
 
 typedef struct _eparam {
-   char *	key;		/* name of the parameter */
-   u_char	pointno;	/* point number in point array, for polygons */
-   eparamptr	next;		/* next parameter in linked list */
+   char *	key;	    /* name of the parameter */
+   union {
+      int	pointno;    /* point number in point array, for polygons */
+      char	*refkey;    /* parameter reference key, for instances */
+   } pdata;
+   eparamptr	next;	    /* next parameter in linked list */
 } eparam;
 
 /*----------------------------------------------------------------------*/
